@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -40,4 +40,13 @@ abstract class BZPOPBase extends RedisCommand
 
         return array_combine([$key], [[$data[0] => $data[1]]]);
     }
+
+    /**
+     * @param                                       $data
+     * @return array|false|mixed|null[]|string|null
+     */
+    public function parseResp3Response($data)
+    {
+        return $this->parseResponse($data);
+    }
 }
