@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis\CountMinSketch;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 /**
  * @see https://redis.io/commands/cms.merge/
@@ -39,4 +39,17 @@ class CMSMERGE extends RedisCommand
 
         parent::setArguments($processedArguments);
     }
+
+    public function prefixKeys($prefix)
+    {
+        if ($arguments = $this->getArguments()) {
+            $arguments[0] = $prefix . $arguments[0];
+
+            for ($i = 2, $iMax = (int) $arguments[1] + 2; $i < $iMax; $i++) {
+                $arguments[$i] = $prefix . $arguments[$i];
+            }
+
+            $this->setRawArguments($arguments);
+        }
+    }
 }
