@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2023 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis\CuckooFilter;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 use Predis\Command\Traits\BloomFilters\BucketSize;
 use Predis\Command\Traits\BloomFilters\Expansion;
 use Predis\Command\Traits\BloomFilters\MaxIterations;
@@ -49,4 +49,9 @@ class CFRESERVE extends RedisCommand
         $this->setBucketSize($arguments);
         $this->filterArguments();
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixForFirstArgument($prefix);
+    }
 }
