@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 /**
  * @see http://redis.io/commands/eval
@@ -36,4 +36,15 @@ class EVAL_ extends RedisCommand
     {
         return sha1($this->getArgument(0));
     }
+
+    public function prefixKeys($prefix)
+    {
+        if ($arguments = $this->getArguments()) {
+            for ($i = 2; $i < $arguments[1] + 2; ++$i) {
+                $arguments[$i] = "$prefix{$arguments[$i]}";
+            }
+
+            $this->setRawArguments($arguments);
+        }
+    }
 }
