@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 use Predis\Command\Traits\Keys;
 
 /**
@@ -30,4 +30,19 @@ class FCALL extends RedisCommand
     {
         return 'FCALL';
     }
+
+    public function prefixKeys($prefix)
+    {
+        $arguments = $this->getArguments();
+
+        if (isset($arguments[1])) {
+            $numkeys = $arguments[1];
+
+            for ($i = 2; $i < $numkeys + 2; $i++) {
+                $arguments[$i] = $prefix . $arguments[$i];
+            }
+        }
+
+        $this->setRawArguments($arguments);
+    }
 }
