@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis\Json;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 class JSONMGET extends RedisCommand
 {
@@ -33,4 +33,9 @@ class JSONMGET extends RedisCommand
 
         parent::setArguments($unpackedArguments);
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixSkippingLastArgument($prefix);
+    }
 }
