@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis\Search;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 /**
  * @see https://redis.io/commands/ft.explain/
@@ -28,16 +28,30 @@ class FTEXPLAIN extends RedisCommand
 
     public function setArguments(array $arguments)
     {
-        [$index, $query] = $arguments;
-        $commandArguments = [];
+        // If command already deserialized, bypass logic.
+        if (in_array('DIALECT', $arguments)) {
+            parent::setArguments($arguments);
 
-        if (!empty($arguments[2])) {
-            $commandArguments = $arguments[2]->toArray();
+            return;
         }
 
+        [$index, $query] = $arguments;
+
+        if (!empty($arguments[2]) && !in_array('DIALECT', $arguments[2]->toArray())) {
+            // Default dialect is 2
+            $arguments[2]->dialect(2);
+        }
+
+        $commandArguments = (!empty($arguments[2])) ? $arguments[2]->toArray() : ['DIALECT', 2];
+
         parent::setArguments(array_merge(
             [$index, $query],
             $commandArguments
         ));
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixForFirstArgument($prefix);
+    }
 }
