@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2024 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,7 +12,7 @@
 
 namespace Predis\Command\Redis;
 
-use Predis\Command\Command as RedisCommand;
+use Predis\Command\PrefixableCommand as RedisCommand;
 
 /**
  * @see http://redis.io/commands/xadd
@@ -41,6 +41,20 @@ class XADD extends RedisCommand
             $args[] = 'NOMKSTREAM';
         }
 
+        if (isset($options['trimming'])) {
+            $args[] = strtoupper($options['trimming']);
+        }
+
+        // IDMPAUTO or IDMP options (mutually exclusive)
+        if (isset($options['idmpauto'])) {
+            $args[] = 'IDMPAUTO';
+            $args[] = $options['idmpauto'];
+        } elseif (isset($options['idmp']) && is_array($options['idmp'])) {
+            $args[] = 'IDMP';
+            $args[] = $options['idmp'][0]; // pid
+            $args[] = $options['idmp'][1]; // iid
+        }
+
         if (isset($options['trim']) && is_array($options['trim'])) {
             array_push($args, ...$options['trim']);
 
@@ -52,6 +66,7 @@ class XADD extends RedisCommand
 
         // ID, default to * to let Redis set it
         $args[] = $arguments[2] ?? '*';
+
         if (isset($arguments[1]) && is_array($arguments[1])) {
             foreach ($arguments[1] as $key => $val) {
                 $args[] = $key;
@@ -61,4 +76,9 @@ class XADD extends RedisCommand
 
         parent::setArguments($args);
     }
+
+    public function prefixKeys($prefix)
+    {
+        $this->applyPrefixForFirstArgument($prefix);
+    }
 }
