@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -22,14 +22,14 @@ trait Rev
 {
     public function setArguments(array $arguments)
     {
-        $argument = $arguments[static::$revArgumentPositionOffset];
-
-        if (false === $argument) {
+        if (count($arguments) <= static::$revArgumentPositionOffset || false === $arguments[static::$revArgumentPositionOffset]) {
             parent::setArguments($arguments);
 
             return;
         }
 
+        $argument = $arguments[static::$revArgumentPositionOffset];
+
         if (true === $argument) {
             $argument = 'REV';
         } else {
