@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -40,6 +40,13 @@ interface NodeConnectionInterface extends ConnectionInterface
      */
     public function getParameters();
 
+    /**
+     * Returns Client ID assigned by Redis server to current connection.
+     *
+     * @return int|null
+     */
+    public function getClientId(): ?int;
+
     /**
      * Pushes the given command into a queue of commands executed when
      * establishing the actual connection to Redis.
@@ -54,4 +61,20 @@ interface NodeConnectionInterface extends ConnectionInterface
      * @return mixed
      */
     public function read();
+
+    /**
+     * Performs a write operation over the stream of the buffer containing a
+     * command serialized with the Redis wire protocol.
+     *
+     * @param  string $buffer
+     * @return void
+     */
+    public function write(string $buffer): void;
+
+    /**
+     * Checks if current connection has data to read from server.
+     *
+     * @return bool
+     */
+    public function hasDataToRead(): bool;
 }
