@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -858,6 +858,14 @@ class KeyPrefixProcessorTest extends PredisTestCase
                 ['key'],
                 ['prefix:key'],
             ],
+            ['LMPOP',
+                [['key1', 'key2', 'key3'], 'left', 10],
+                [3, 'prefix:key1', 'prefix:key2', 'prefix:key3', 'LEFT', 'COUNT', 10],
+            ],
+            ['BLMPOP',
+                [10, ['key1', 'key2', 'key3'], 'left', 10],
+                [10, 3, 'prefix:key1', 'prefix:key2', 'prefix:key3', 'LEFT', 'COUNT', 10],
+            ],
             /* ---------------- Redis 7.4 ---------------- */
             ['HEXPIRE',
                 ['key', 10, ['field1', 'field2']],
