@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,6 +12,8 @@
 
 namespace Predis\Command\Redis;
 
+use Predis\Command\PrefixableCommand;
+
 class HPTTL_Test extends PredisCommandTestCase
 {
     /**
@@ -52,6 +54,21 @@ class HPTTL_Test extends PredisCommandTestCase
         $this->assertSame(1, $command->parseResponse(1));
     }
 
+    /**
+     * @group disconnected
+     */
+    public function testPrefixKeys(): void
+    {
+        /** @var PrefixableCommand $command */
+        $command = $this->getCommand();
+        $command->setArguments(['key', ['field1', 'field2']]);
+
+        // After setArguments, the arguments are transformed to: ['key', 'FIELDS', 2, 'field1', 'field2']
+        $command->prefixKeys('prefix:');
+
+        $this->assertSame(['prefix:key', 'FIELDS', 2, 'field1', 'field2'], $command->getArguments());
+    }
+
     /**
      * @group connected
      * @return void
