@@ -4,7 +4,7 @@
  * This file is part of the Predis package.
  *
  * (c) 2009-2020 Daniele Alessandri
- * (c) 2021-2025 Till Krüss
+ * (c) 2021-2026 Till Krüss
  *
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
@@ -12,6 +12,8 @@
 
 namespace Predis\Command\Redis;
 
+use Predis\Command\PrefixableCommand;
+
 /**
  * @group commands
  * @group realm-list
@@ -104,6 +106,23 @@ class LMPOP_Test extends PredisCommandTestCase
         $this->assertSame(['elem2', 'elem1'], $redis->lrange('key', 0, -1));
     }
 
+    /**
+     * @group disconnected
+     */
+    public function testPrefixKeys(): void
+    {
+        /** @var PrefixableCommand $command */
+        $command = $this->getCommand();
+        $actualArguments = [['key1', 'key2'], 'left', 10];
+        $prefix = 'prefix:';
+        $expectedArguments = [2, 'prefix:key1', 'prefix:key2', 'LEFT', 'COUNT', 10];
+
+        $command->setArguments($actualArguments);
+        $command->prefixKeys($prefix);
+
+        $this->assertSame($expectedArguments, $command->getArguments());
+    }
+
     public function argumentsProvider(): array
     {
         return [
